@@ -8,8 +8,6 @@ from typing import (
     TYPE_CHECKING,
 )
 
-from .style import Style
-
 if TYPE_CHECKING:
     from .console import (
         Console,
@@ -41,9 +39,11 @@ class Renderables:
         """Console render method to insert line-breaks."""
         yield from self._renderables
 
-    def __rich_measure__(self, console: "Console", max_width: int) -> "Measurement":
+    def __rich_measure__(
+        self, console: "Console", options: "ConsoleOptions"
+    ) -> "Measurement":
         dimensions = [
-            Measurement.get(console, renderable, max_width)
+            Measurement.get(console, options, renderable)
             for renderable in self._renderables
         ]
         if not dimensions:
@@ -101,6 +101,9 @@ class Lines:
     def extend(self, lines: Iterable["Text"]) -> None:
         self._lines.extend(lines)
 
+    def pop(self, index=-1) -> "Text":
+        return self._lines.pop(index)
+
     def justify(
         self,
         console: "Console",
