@@ -46,6 +46,8 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "inspect.doc": Style(dim=True),
     "inspect.value.border": Style(color="green"),
     "live.ellipsis": Style(bold=True, color="red"),
+    "layout.tree.row": Style(dim=False, color="red"),
+    "layout.tree.column": Style(dim=False, color="blue"),
     "logging.keyword": Style(bold=True, color="yellow"),
     "logging.level.notset": Style(dim=True),
     "logging.level.debug": Style(color="green"),
@@ -74,7 +76,7 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "repr.attrib_name": Style(color="yellow", italic=False),
     "repr.attrib_equal": Style(bold=True),
     "repr.attrib_value": Style(color="magenta", italic=False),
-    "repr.number": Style(color="blue", bold=True, italic=False),
+    "repr.number": Style(color="cyan", bold=True, italic=False),
     "repr.bool_true": Style(color="bright_green", italic=True),
     "repr.bool_false": Style(color="bright_red", italic=True),
     "repr.none": Style(color="magenta", italic=True),
@@ -99,7 +101,7 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "table.cell": Style.null(),
     "table.title": Style(italic=True),
     "table.caption": Style(italic=True, dim=True),
-    "traceback.error": Style(dim=True, color="red", bold=True),
+    "traceback.error": Style(color="red", italic=True),
     "traceback.border.syntax_error": Style(color="bright_red"),
     "traceback.border": Style(color="red"),
     "traceback.text": Style.null(),
